<html><head><title>Testshop</title></head><body>
<!--
   Netpay-Democode fuer XML-Interface
   Modul:         refundtext, Testmodul fuer EPS refund
   Author:        Ludwig Ertl  (ludwig.ertl@softwerker.at)
   Last modified: 10.01.2019
   History:       10.01.2019 - Initial version
-->
<?
    include("netpay_functions.inc.php");
    include("netpay_refund_functions.inc.php");
    
    $preis="0.90";

    if ($_REQUEST['id'])
	{
		print_r(EPS_Refund_Initiate($_REQUEST['id'], $_REQUEST['preis'], $_REQUEST));
	}
?>    
<form>
 <table>
  <tr><td style="background-color:lightgrey;">Preis</td><td style="background-color:lightyellow;"><input type="text" name="preis" size=6 value="<?=$preis?>"></td></tr>
  <tr><td style="background-color:lightgrey;">Referenz:</td><td style="background-color:lightyellow;"><input type=text size=23 maxlength=50 name="id"></td></tr>
  <tr><td style="background-color:lightgrey;">Bank:</td><td style="background-color:lightyellow;">
    <select name="Bank">
    <?ListBanks();?>
    </select>
</td></tr>
  <tr><td style="background-color:lightgrey;">(optional) Merchant IBAN:</td><td><input type=text size=23 maxlength=50 name="MerchantIBAN"></td></tr>
  <tr><td style="background-color:lightgrey;">(optional) Refund Reference:</td><td><input type=text size=23 maxlength=50 name="RefundReference"></td></tr>
 </table>
 <input type=submit value="Erstatten!">
</form>
</body></html>